/***********************************************************/
/*   Create and Write to Compressed and Chunked Dataset    */ 
/***********************************************************/

#include "hdf5.h"
#define FILE "dset.h5"

int main() {

   hid_t       file_id, dataset_id, dataspace_id;  /* identifiers */
   hsize_t     dims[2];
   herr_t      status;
   int         i, j, dset_data[4][6];

   /************************************/
   /* Definitions needed to create a   */
   /* Compressed chunked Dataset.      */
   /************************************/

   hid_t    pid;
   hsize_t  cdims[2] = {2,3}; 
   /************************************/
   

   /* Initialize the dataset. */
   for (i = 0; i < 4; i++)
      for (j = 0; j < 6; j++)
         dset_data[i][j] = i * 6 + j + 1;


   /* Create a new file using default properties. */
   file_id = H5Fcreate(FILE, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);

   /* Create the data space for the dataset. */
   dims[0] = 4; 
   dims[1] = 6; 
   dataspace_id = H5Screate_simple(2, dims, NULL);

   /***************************************************************/
   /* Create a compressed chunked dataset                         */
   /***************************************************************/

    pid  = H5Pcreate(H5P_DATASET_CREATE);
    printf ("H5Pcreate returns: %d\n", pid);
    status = H5Pset_chunk(pid, 2, cdims);
    printf ("H5Pset_chunk returns: %d\n", status);
    status = H5Pset_deflate(pid, 6);
    printf ("H5Pset_deflate returns: %d\n", status);

    dataset_id = H5Dcreate(file_id, "/dset", H5T_STD_I32BE, dataspace_id, pid);
   /***************************************************************/


   /* Write the dataset. */
   status = H5Dwrite(dataset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, 
                     dset_data);

   status = H5Dread(dataset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, 
                    dset_data);

   /* Terminate access to the dataspace, dataset, file */
   status = H5Sclose(dataspace_id);
   status = H5Dclose(dataset_id);
   status = H5Fclose(file_id);

   /***************************************************************/
   /* Needed if creating a compressed chunked dataset             */
   /***************************************************************/

   status = H5Pclose (pid);
   /***************************************************************/

   

}
