/***********************************************************/
/*   Create an Unlimited Dimension Dataset                 */ 
/*   Select and write to Extended Portion                  */
/***********************************************************/

#include "hdf5.h"
#define FILE "dset.h5"

int main() {

   hid_t       file_id, dataset_id, dataspace_id;  /* identifiers */
   hsize_t     dims[2];
   herr_t      status;
   int         i, j, dset_data[4][6];
   hid_t       pid;
   hsize_t     cdims[2] = {2,3}; 

   /****************************************/
   /* NEW - to extend and write hyperslab  */ 
   /****************************************/
   hsize_t     maxdims[2] = {H5S_UNLIMITED, 6};
   hsize_t     dims1[2]={2,6}; 
   hid_t       memspace, filespace;
   int         data1[2][6]= { {1, 1, 1, 1, 1, 1}, 
                              {2, 2, 2, 2, 2, 2}}; 
   hsize_t     size[2] = {6, 6};
   hsize_t     offset[2] ;
   /****************************************/

   /* Initialize the dataset. */
   for (i = 0; i < 4; i++)
      for (j = 0; j < 6; j++)
         dset_data[i][j] = i * 6 + j + 1;


   /* Create a new file using default properties. */
   file_id = H5Fcreate(FILE, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);

   /* Create the data space for the dataset. */
   dims[0] = 4; 
   dims[1] = 6; 
   
  
   /*********************************************/
   /* NEW - Create unlimited dimension dataset  */
   /*********************************************/
   dataspace_id = H5Screate_simple(2, dims, maxdims);
   /*********************************************/

   pid  = H5Pcreate(H5P_DATASET_CREATE);
   printf ("H5Pcreate returns: %d\n", pid);
   status = H5Pset_chunk(pid, 2, cdims);
   printf ("H5Pset_chunk returns: %d\n", status);

    dataset_id = H5Dcreate(file_id, "/dset", H5T_STD_I32BE, dataspace_id, pid);
   

   /* Write the dataset. */
   status = H5Dwrite(dataset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, 
                     dset_data);
  
   /******************************************************/
   /* NEW - Extend Dataset and Write to extended Portion */
   /******************************************************/

   size[0] = 6;
   size[1] = 6;
   status = H5Dextend (dataset_id, size);

   filespace = H5Dget_space (dataset_id);
   offset[0] = 4;
   offset[1] = 0;
   memspace = H5Screate_simple (2, dims1, NULL);

   status = H5Sselect_hyperslab (filespace, H5S_SELECT_SET, offset, NULL,
                                  dims1, NULL); 

   status = H5Dwrite(dataset_id, H5T_NATIVE_INT, memspace, filespace, H5P_DEFAULT, 
                     data1);
   /*****************************************************/

   /* Terminate access to the dataspace, dataset, file */
   status = H5Pclose (pid);
   status = H5Sclose(dataspace_id);
   status = H5Dclose(dataset_id);
   status = H5Fclose(file_id);

   /******************************************************/
   /* NEW - Needed to write to extended portion          */
   /******************************************************/
   status = H5Sclose (memspace);
   status = H5Sclose (filespace);
   /******************************************************/


}
