/***************************************************************/ 
/*  Create and Write to a Dataset.  Add attribute.             */
/***************************************************************/ 

#include "hdf5.h"
#define FILE "dset.h5"

int main() {

   hid_t       file_id, dataset_id, dataspace_id;  /* identifiers */
   hid_t       aspace_id;
   hsize_t     dims[2], dimsa;
   herr_t      status;
   int         i, j, dset_data[4][6];

   /*******************/
   /* Attribute       */
   /*******************/
   int         attr_data[2] = {100,200};
   hid_t       attribute_id;
   /*******************/
   

   /* Initialize the dataset. */
   for (i = 0; i < 4; i++)
      for (j = 0; j < 6; j++)
         dset_data[i][j] = i * 6 + j + 1;


   /* Create a new file using default properties. */
   file_id = H5Fcreate(FILE, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);

   /* Create the data space for the dataset. */
   dims[0] = 4; 
   dims[1] = 6; 
   dataspace_id = H5Screate_simple(2, dims, NULL);

   /* Create the dataset. */
   dataset_id = H5Dcreate(file_id, "/dset", H5T_STD_I32BE, dataspace_id, H5P_DEFAULT);

   /* Write the dataset. */
   status = H5Dwrite(dataset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, 
                     dset_data);

   status = H5Dread(dataset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, 
                    dset_data);

   /*******************/
   /* Add attribute   */
   /*******************/

   dimsa = 2;
   aspace_id = H5Screate_simple(1, &dimsa, NULL);

   attribute_id = H5Acreate (dataset_id, "Units", H5T_STD_I32BE, aspace_id, 
                             H5P_DEFAULT);
   status = H5Awrite (attribute_id, H5T_NATIVE_INT, attr_data);
   status = H5Aclose (attribute_id);
   /*******************/

   /* Terminate access to the dataspace, dataset, file */
   status = H5Sclose(dataspace_id);
   status = H5Sclose(aspace_id);
   status = H5Dclose(dataset_id);
   status = H5Fclose(file_id);

}
