/***************************************************************/ 
/*  Create and Write to a Dataset in Group "mygroup"           */
/***************************************************************/ 

#include "hdf5.h"
#define FILE "dset.h5"

int main() {

   hid_t       file_id, dataset_id, dataspace_id, group_id; 
   hsize_t     dims[2];
   herr_t      status;
   int         i, j, dset_data[4][6];

   /* Initialize the dataset. */
   for (i = 0; i < 4; i++)
      for (j = 0; j < 6; j++)
         dset_data[i][j] = i * 6 + j + 1;


   /* Create a new file using default properties. */
   file_id = H5Fcreate (FILE, H5F_ACC_TRUNC, H5P_DEFAULT, H5P_DEFAULT);

   /* Create a group under the root group */
   /* called "mygroup".                   */

   group_id = H5Gcreate (file_id, "mygroup", 0);

   /* Create the data space for the dataset. */
   dims[0] = 4; 
   dims[1] = 6; 
   dataspace_id = H5Screate_simple (2, dims, NULL);

   /* Create the dataset under "mygroup".  */
   /* Note that the location ID is the     */
   /* Group identifier.                    */

   dataset_id = H5Dcreate (group_id, "dset", H5T_STD_I32BE, dataspace_id, H5P_DEFAULT);


   /* Write the dataset. */
   status = H5Dwrite (dataset_id, H5T_NATIVE_INT, H5S_ALL, H5S_ALL, H5P_DEFAULT, 
                      dset_data);

   /* Terminate access to the group, dataspace, dataset, file */
   status = H5Gclose (group_id);
   status = H5Sclose (dataspace_id);
   status = H5Dclose (dataset_id);
   status = H5Fclose (file_id);

}
